summaryrefslogtreecommitdiffstats
path: root/Lib/idlelib/editor.py
diff options
context:
space:
mode:
authorTerry Jan Reedy <tjreedy@udel.edu>2018-06-21 01:25:59 (GMT)
committerGitHub <noreply@github.com>2018-06-21 01:25:59 (GMT)
commita361e89d5ae3daefe9e8b8a7e889cd2ad8c45b77 (patch)
treef213feb31b204946297645de94ca774ca65fd777 /Lib/idlelib/editor.py
parent87a927325e3856621790a39d8718ff24a19510aa (diff)
downloadcpython-a361e89d5ae3daefe9e8b8a7e889cd2ad8c45b77.zip
cpython-a361e89d5ae3daefe9e8b8a7e889cd2ad8c45b77.tar.gz
cpython-a361e89d5ae3daefe9e8b8a7e889cd2ad8c45b77.tar.bz2
bpo-33906: Rename idlelib.windows as window (#7833)
Match Window on the main menu and remove last plural module name. Change imports, test, and attribute references to match new name.
Diffstat (limited to 'Lib/idlelib/editor.py')
-rw-r--r--Lib/idlelib/editor.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/Lib/idlelib/editor.py b/Lib/idlelib/editor.py
index b463165..3f034f8 100644
--- a/Lib/idlelib/editor.py
+++ b/Lib/idlelib/editor.py
@@ -25,7 +25,7 @@ from idlelib import pyparse
from idlelib import query
from idlelib import replace
from idlelib import search
-from idlelib import windows
+from idlelib import window
# The default tab setting for a Text widget, in average-width characters.
TK_TABWIDTH_DEFAULT = 8
@@ -101,7 +101,7 @@ class EditorWindow(object):
root = root or flist.root
self.root = root
self.menubar = Menu(root)
- self.top = top = windows.ListedToplevel(root, menu=self.menubar)
+ self.top = top = window.ListedToplevel(root, menu=self.menubar)
if flist:
self.tkinter_vars = flist.vars
#self.top.instance_dict makes flist.inversedict available to
@@ -138,7 +138,7 @@ class EditorWindow(object):
self.top.protocol("WM_DELETE_WINDOW", self.close)
self.top.bind("<<close-window>>", self.close_event)
if macosx.isAquaTk():
- # Command-W on editorwindows doesn't work without this.
+ # Command-W on editor windows doesn't work without this.
text.bind('<<close-window>>', self.close_event)
# Some OS X systems have only one mouse button, so use
# control-click for popup context menus there. For two
@@ -276,7 +276,7 @@ class EditorWindow(object):
menu.add_separator()
end = end + 1
self.wmenu_end = end
- windows.register_callback(self.postwindowsmenu)
+ window.register_callback(self.postwindowsmenu)
# Some abstractions so IDLE extensions are cross-IDE
self.askyesno = tkMessageBox.askyesno
@@ -436,14 +436,14 @@ class EditorWindow(object):
self.reset_help_menu_entries()
def postwindowsmenu(self):
# Only called when Windows menu exists
menu = self.menudict['windows']
end = menu.index("end")
if end is None:
end = -1
if end > self.wmenu_end:
menu.delete(self.wmenu_end+1, end)
- windows.add_windows_to_menu(menu)
+ window.add_windows_to_menu(menu)
def handle_yview(self, event, *args):
"Handle scrollbar."
@@ -1012,7 +1012,7 @@ class EditorWindow(object):
def _close(self):
if self.io.filename:
self.update_recent_files_list(new_file=self.io.filename)
- windows.unregister_callback(self.postwindowsmenu)
+ window.unregister_callback(self.postwindowsmenu)
self.unload_extensions()
self.io.close()
self.io = None
@@ -436,14 +436,14 @@ class EditorWindow(object):
self.reset_help_menu_entries()
def postwindowsmenu(self):
- # Only called when Windows menu exists
+ # Only called when Window menu exists
menu = self.menudict['windows']
end = menu.index("end")